==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/br.js <==
OC.L10N.register(
    "lib",
    {
    "See %s" : "Sellet %s",
    "Other activities" : "Oberiantizoù all",
    "PHP %s or higher is required." : "PHP %s pe hueloc'h a zo ret kaout.",
    "PHP with a version lower than %s is required." : "PHP gant ur stumm izeloc'h eget %s a zo ret kaout.",
    "The library %s is not available." : "Al levraoueg %s ne c'hell ket bezhgañ implijet",
    "Server version %s or higher is required." : "Stumm servijour %s pe hueloc'h rekis",
    "Unknown filetype" : "N'eo ket anavezet stumm an teuliad",
    "Invalid image" : "N'eo ket aotreet ar skeudenn",
    "today" : "hiziv",
    "yesterday" : "dec'h",
    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
    "last month" : "ar miz tremenet",
    "_%n month ago_::_%n months ago_" : ["%n miz zo","%n miz zo","%n miz zo","%n miz zo","%n miz zo"],
    "next year" : "bloaz war-lerc'h",
    "last year" : "Ar bloaz tremenet",
    "_%n year ago_::_%n years ago_" : ["%n bloaz zo","%n bloaz zo","%n bloaz zo","%n bloaz zo","%n bloaz zo"],
    "_%n hour ago_::_%n hours ago_" : ["%n hervez zo","%n hervez zo","%n hervez zo","%n hervez zo","%n hervez zo"],
    "_%n minute ago_::_%n minutes ago_" : ["%n munudenn-zo","%n munudenn-zo","%n munudenn-zo","%n munudenn-zo","%n munudenn-zo"],
    "seconds ago" : "eilenn zo",
    "File name contains at least one invalid character" : "Un arouez fall ez eus d'an neubeutañ en anv restr",
    "File name is too long" : "Anv ar restr a zo re hir",
    "Empty filename is not allowed" : "Un anv-restr goulo n'eo ket aotreet",
    "__language_name__" : "Brezhoneg",
    "Help" : "Skoazell",
    "Apps" : "Meziant",
    "Settings" : "Arventennoù",
    "Log out" : "Kuitat",
    "Users" : "Implijer",
    "Email" : "Postel",
    "Twitter" : "Twitter",
    "Website" : "Lec'hien web",
    "Address" : "Chom-lec'h",
    "Profile picture" : "Skeudenn trolinenn",
    "About" : "Diwar-benn",
    "Full name" : "Tout an anv",
    "Role" : "Roll",
    "Unknown user" : "Implijer dianv",
    "Additional settings" : "Stummoù ouzhpenn",
    "Set an admin username." : "Lakaat un anv-impljer merour.",
    "Set an admin password." : "Lakaat ur ger-tremenn merour.",
    "Sharing backend for %s not found" : "Rannadenn backend evit %s n'eo ket bet kavet",
    "Open »%s«" : "Digeriñ  »%s«",
    "Monday" : "Lun",
    "The username is already being used" : "An anv-implijet a zo dija implijet",
    "User disabled" : "Implijer disaotreet",
    "Login canceled by app" : "Mont tre arrestet gant ar meziant",
    "Application is not enabled" : "N'eo ket aotreet ar meziant",
    "Authentication error" : "Fazi dilesa",
    "Token expired. Please reload page." : "Jedouer re gozh. Adkargit ar bajenn.",
    "PHP module %s not installed." : "Modul %s PHPn n'eo ket staliet.",
    "Storage connection error. %s" : "Fazi renkañ kenstag. %s",
    "Storage is temporarily not available" : "N'haller ket tizhout ar skor roadennoù evit ar poent"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-31.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/br.js <==
OC.L10N.register(
    "lib",
    {
    "See %s" : "Sellet %s",
    "Other activities" : "Oberiantizoù all",
    "PHP %s or higher is required." : "PHP %s pe hueloc'h a zo ret kaout.",
    "PHP with a version lower than %s is required." : "PHP gant ur stumm izeloc'h eget %s a zo ret kaout.",
    "The library %s is not available." : "Al levraoueg %s ne c'hell ket bezhgañ implijet",
    "Server version %s or higher is required." : "Stumm servijour %s pe hueloc'h rekis",
    "Unknown filetype" : "N'eo ket anavezet stumm an teuliad",
    "Invalid image" : "N'eo ket aotreet ar skeudenn",
    "Files" : "Restroù",
    "View profile" : "Gwelet ar profil",
    "today" : "hiziv",
    "tomorrow" : "arc'hoazh",
    "yesterday" : "dec'h",
    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
    "last month" : "ar miz tremenet",
    "_%n month ago_::_%n months ago_" : ["%n miz zo","%n miz zo","%n miz zo","%n miz zo","%n miz zo"],
    "next year" : "bloaz war-lerc'h",
    "last year" : "Ar bloaz tremenet",
    "_%n year ago_::_%n years ago_" : ["%n bloaz zo","%n bloaz zo","%n bloaz zo","%n bloaz zo","%n bloaz zo"],
    "_%n hour ago_::_%n hours ago_" : ["%n hervez zo","%n hervez zo","%n hervez zo","%n hervez zo","%n hervez zo"],
    "_%n minute ago_::_%n minutes ago_" : ["%n munudenn-zo","%n munudenn-zo","%n munudenn-zo","%n munudenn-zo","%n munudenn-zo"],
    "seconds ago" : "eilenn zo",
    "Filename contains at least one invalid character" : "Bez ez eus d'an neubeutan un arouez diffenet en anv restr",
    "Empty filename is not allowed" : "Un anv-restr goulo n'eo ket aotreet",
    "__language_name__" : "Brezhoneg",
    "Apps" : "Meziant",
    "Settings" : "Arventennoù",
    "Log out" : "Digennaskañ",
    "Accounts" : "Kontoù",
    "Email" : "Postel",
    "Twitter" : "Twitter",
    "Website" : "Lec'hienn web",
    "Address" : "Chom-lec'h",
    "Profile picture" : "Skeudenn brofil",
    "About" : "Diwar-benn",
    "Display name" : "Anv ardivink",
    "Role" : "Roll",
    "Additional settings" : "Stummoù ouzhpenn",
    "Set an admin password." : "Lakaat ur ger-tremenn merour.",
    "Sharing backend for %s not found" : "Rannadenn backend evit %s n'eo ket bet kavet",
    "Sunday" : "Sul",
    "Monday" : "Lun",
    "Wednesday" : "Merc'her",
    "Friday" : "Gwener",
    "Mon." : "Lun",
    "Fri." : "Gwe.",
    "Sat." : "Sad.",
    "January" : "Genver",
    "February" : "C'hwevrer",
    "March" : "Meurzh",
    "April" : "Ebrel",
    "May" : "Mae",
    "June" : "Even",
    "July" : "Gouere",
    "August" : "Eost",
    "September" : "Gwengolo",
    "October" : "Here",
    "November" : "Du",
    "December" : "Kerdu",
    "Feb." : "C'hw.",
    "May." : "Mae.",
    "Jun." : "Even",
    "Aug." : "Eost",
    "Nov." : "Du",
    "Dec." : "Ker.",
    "Login canceled by app" : "Mont tre arrestet gant ar meziant",
    "Application is not enabled" : "N'eo ket aotreet ar meziant",
    "Authentication error" : "Fazi dilesa",
    "Token expired. Please reload page." : "Jedouer re gozh. Adkargit ar bajenn.",
    "PHP module %s not installed." : "Modul %s PHPn n'eo ket staliet.",
    "Storage connection error. %s" : "Fazi renkañ kenstag. %s",
    "Storage is temporarily not available" : "N'haller ket tizhout ar skor roadennoù evit ar poent",
    "Text" : "Testenn",
    "Summary" : "Diverrañ",
    "Translate" : "Treiñ",
    "File name contains at least one invalid character" : "Un arouez fall ez eus d'an neubeutañ en anv restr",
    "File name is too long" : "Anv ar restr a zo re hir",
    "Users" : "Implijer",
    "Open »%s«" : "Digeriñ  »%s«"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
